@@ -51,7 +51,7 @@ class Graph2Vec(Estimator):
             * **graphs** *(List of NetworkX graphs)* - The graphs to be embedded.
         """
         self._set_seed()
-        self._check_graphs(graphs)
+        graphs = self._check_graphs(graphs)
         documents = [WeisfeilerLehmanHashing(graph, self.wl_iterations, self.attributed, self.erase_base_features) for graph in graphs]
         documents = [TaggedDocument(words=doc.get_graph_features(), tags=[str(i)]) for i, doc in enumerate(documents)]
 
@@ -62,7 +62,7 @@ class Graph2Vec(Estimator):
                         dm=0,
                         sample=self.down_sampling,
                         workers=self.workers,
-                        iter=self.epochs,
+                        epochs=self.epochs,
                         alpha=self.learning_rate,
                         seed=self.seed)
 
